@@ -7,22 +7,20 @@
 #include "../kwalletmanager_version.h"
 #include "kwalletmanager.h"
 
-#include <KDBusAddons/kdbusservice.h>
+#include <KDBusService>
 #include <KLocalizedString>
 #include <KAboutData>
 
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QFile>
-#include <QFileInfo>
-#include <QMimeDatabase>
-#include <QMimeType>
 #include <KCrash>
 
 int main(int argc, char **argv)
 {
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+#endif
     QApplication a(argc, argv);
     KCrash::initialize();
     KLocalizedString::setApplicationDomain("kwalletmanager");
@@ -51,12 +49,8 @@ int main(int argc, char **argv)
                         i18n("Developer"),
                         QStringLiteral("isaac@warp.es"));
 
-    aboutData.setOrganizationDomain("kde.org");
-
     KAboutData::setApplicationData(aboutData);
 
-    KDBusService dbssvc(KDBusService::Unique);
-
     QCommandLineParser parser;
 
     aboutData.setupCommandLine(&parser);
@@ -65,31 +59,12 @@ int main(int argc, char **argv)
     parser.addPositionalArgument(QStringLiteral("name"), i18n("A wallet name"));
     parser.process(a);
     aboutData.processCommandLine(&parser);
-    KWalletManager wm;
-    QObject::connect(&dbssvc, &KDBusService::activateRequested, &wm, &QWidget::activateWindow);
 
-    if (parser.isSet(QStringLiteral("show"))) {
-        wm.show();
-    }
+    KDBusService dbssvc(KDBusService::Unique);
 
-    if (parser.isSet(QStringLiteral("kwalletd"))) {
-        wm.kwalletdLaunch();
-    }
-
-    const QStringList arguments = parser.positionalArguments();
-    for (int i = 0; i < arguments.count(); ++i) {
-        QString fn = QFileInfo(arguments.at(i)).absoluteFilePath();
-        if (QFile::exists(fn)) {
-            QMimeDatabase mimeDb;
-            QMimeType mt = mimeDb.mimeTypeForFile(fn, QMimeDatabase::MatchContent);
-
-            if (mt.isValid() && mt.inherits(QStringLiteral("application/x-kwallet"))) {
-                wm.openWalletFile(fn);
-            }
-        } else {
-            wm.openWallet(arguments.at(i));
-        }
-    }
+    KWalletManager wm(&parser);
+    QObject::connect(&dbssvc, &KDBusService::activateRequested, &wm, &KWalletManager::handleActivate);
+    QObject::connect(&dbssvc, &KDBusService::openRequested, &wm, &KWalletManager::handleOpen);
 
     return a.exec();
 }
